morphemepiece_vocab: Load a Morphemepiece Vocabulary
Description
A morphemepiece vocabulary is a named integer vector with class
"morphemepiece_vocabulary". The names of the vector are the morphemes, and
the values are the integer identifiers of those tokens. The vocabulary is
0-indexed for compatibility with Python implementations.